@@ -24,6 +24,10 @@ class TexnoMagicAlphabet:
     def symbols_path(self):
         return self.path / 'symbols'
 
+    @property
+    def handle(self):
+        return common.name2handle(self.name)
+
     @property
     def symbols(self):
         if self._symbols is None:
