@@ -29,6 +29,10 @@ class TexnoMagicSymbol:
     def model_path(self):
         return self.path / 'model'
 
+    @property
+    def handle(self):
+        return common.name2handle(self.name)
+
     @property
     def model(self):
         if self._model is None:
